@@ -66,6 +66,9 @@ sorted_classifiers: List[str] = [
     "Environment :: Web Environment :: Buffet",
     "Environment :: Web Environment :: Mozilla",
     "Environment :: Web Environment :: ToscaWidgets",
+    "Environment :: WebAssembly",
+    "Environment :: WebAssembly :: Emscripten",
+    "Environment :: WebAssembly :: WASI",
     "Environment :: Win32 (MS Windows)",
     "Environment :: X11 Applications",
     "Environment :: X11 Applications :: GTK",
